@@ -33,16 +33,13 @@
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <getdns/getdns_ext_libevent.h>
-#include "config.h"
 #include <sys/time.h>
+#include "getdns/getdns_ext_libevent.h"
+#include "config.h"
 
 #ifdef HAVE_EVENT2_EVENT_H
 #  include <event2/event.h>
 #else
-#  ifndef u_char
-#    define u_char unsigned char
-#  endif
 #  include <event.h>
 #  define evutil_socket_t int
 #  define event_free free
