@@ -36,7 +36,7 @@
 #ifndef _GETDNS_GENERAL_H_
 #define _GETDNS_GENERAL_H_
 
-#include <getdns/getdns.h>
+#include "getdns/getdns.h"
 #include "types-internal.h"
 
 /* private inner helper used by sync and async */
